==> apache-datafusion-comet-0.11.0.tar.gz: apache-datafusion-comet-0.11.0/docs/source/conf.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

# -- Project information -----------------------------------------------------

project = 'Apache DataFusion Comet'
copyright = '2023-2024, Apache Software Foundation'
author = 'Apache Software Foundation'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.doctest',
    'sphinx.ext.ifconfig',
    'sphinx.ext.mathjax',
    'sphinx.ext.viewcode',
    'sphinx.ext.napoleon',
    'myst_parser',
    'sphinx_reredirects',
]

source_suffix = {
    '.rst': 'restructuredtext',
    '.md': 'markdown',
}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []

# Show members for classes in .. autosummary
autodoc_default_options = {
    "members": None,
    "undoc-members": None,
    "show-inheritance": None,
    "inherited-members": None,
}

autosummary_generate = True

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'pydata_sphinx_theme'

html_theme_options = {
    "use_edit_page_button": True,
}

html_context = {
    "github_user": "apache",
    "github_repo": "datafusion-comet",
    "github_version": "main",
    "doc_path": "docs/source",
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_logo = "_static/images/DataFusionComet-Logo-Light.png"

html_css_files = [
    "theme_overrides.css"
]

html_js_files = [
    ("https://buttons.github.io/buttons.js", {'async': 'true', 'defer': 'true'}),
]

html_sidebars = {
    "**": ["docs-sidebar.html"],
}

# tell myst_parser to auto-generate anchor links for headers h1, h2, h3
myst_heading_anchors = 3

# enable nice rendering of checkboxes for the task lists
myst_enable_extensions = ["colon_fence", "deflist", "tasklist"]

redirects = {
    "user-guide/overview.html": "../overview.html",
    "user-guide/gluten_comparison.html": "../gluten_comparison.html",
    "user-guide/compatibility.html": "latest/compatibility.html",
    "user-guide/configs.html": "latest/configs.html",
    "user-guide/datasource.html": "latest/datasource.html",
    "user-guide/datatypes.html": "latest/datatypes.html",
    "user-guide/expressions.html": "latest/expressions.html",
    "user-guide/iceberg.html": "latest/iceberg.html",
    "user-guide/installation.html": "latest/installation.html",
    "user-guide/kubernetes.html": "latest/kubernetes.html",
    "user-guide/metrics.html": "latest/metrics.html",
    "user-guide/operators.html": "latest/operators.html",
    "user-guide/source.html": "latest/source.html",
    "user-guide/tuning.html": "latest/tuning.html",
}

==> apache-datafusion-comet-0.12.0.tar.gz: apache-datafusion-comet-0.12.0/docs/source/conf.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

# -- Project information -----------------------------------------------------

project = 'Apache DataFusion Comet'
copyright = '2023-2024, Apache Software Foundation'
author = 'Apache Software Foundation'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.doctest',
    'sphinx.ext.ifconfig',
    'sphinx.ext.mathjax',
    'sphinx.ext.viewcode',
    'sphinx.ext.napoleon',
    'myst_parser',
    'sphinx_reredirects',
]

source_suffix = {
    '.rst': 'restructuredtext',
    '.md': 'markdown',
}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []

# Show members for classes in .. autosummary
autodoc_default_options = {
    "members": None,
    "undoc-members": None,
    "show-inheritance": None,
    "inherited-members": None,
}

autosummary_generate = True

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'pydata_sphinx_theme'

html_logo = "_static/images/DataFusionComet-Logo-Light.png"

html_theme_options = {
    "logo": {
        "image_light": "_static/images/DataFusionComet-Logo-Light.png",
        "image_dark": "_static/images/DataFusionComet-Logo-Dark.png",
    },

    "use_edit_page_button": False,
    "secondary_sidebar_items": [],
    "collapse_navigation": True,
    "navbar_start": ["navbar-logo"],
    "navbar_center": ["navbar-nav"],
    "navbar_end": ["navbar-icon-links", "theme-switcher"],
    "icon_links": [
        {
            "name": "GitHub",
            "url": "https://github.com/apache/datafusion-comet",
            "icon": "fa-brands fa-github",
        },
    ],

}

html_context = {
    "default_mode": "light",
    "github_user": "apache",
    "github_repo": "datafusion-comet",
    "github_version": "main",
    "doc_path": "docs/source",
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_css_files = [
    "theme_overrides.css"
]

html_js_files = [
    ("https://buttons.github.io/buttons.js", {'async': 'true', 'defer': 'true'}),
]

html_sidebars = {
    "**": ["docs-sidebar.html"],
}

# tell myst_parser to auto-generate anchor links for headers h1, h2, h3
myst_heading_anchors = 3

# enable nice rendering of checkboxes for the task lists
myst_enable_extensions = ["colon_fence", "deflist", "tasklist"]

redirects = {
    "overview.html": "about/index.html",
    "gluten_comparison.html": "about/gluten_comparison.html",
    "user-guide/overview.html": "../about/overview.html",
    "user-guide/gluten_comparison.html": "../about/gluten_comparison.html",
    "user-guide/compatibility.html": "latest/compatibility.html",
    "user-guide/configs.html": "latest/configs.html",
    "user-guide/datasource.html": "latest/datasource.html",
    "user-guide/datatypes.html": "latest/datatypes.html",
    "user-guide/expressions.html": "latest/expressions.html",
    "user-guide/iceberg.html": "latest/iceberg.html",
    "user-guide/installation.html": "latest/installation.html",
    "user-guide/kubernetes.html": "latest/kubernetes.html",
    "user-guide/metrics.html": "latest/metrics.html",
    "user-guide/operators.html": "latest/operators.html",
    "user-guide/source.html": "latest/source.html",
    "user-guide/tuning.html": "latest/tuning.html",
}
